@@ -53,7 +53,8 @@ def signature(dbus_object, *, unpack=False):
         len_sigs = len(sigs)
         if len_sigs > 1:
             raise IntoDPSignatureError(
-                f"the dbus-python Array object {dbus_object} has items with varying signatures",
+                "the dbus-python Array object %s has items with varying signatures"
+                % dbus_object,
                 dbus_object,
             )
 
@@ -77,8 +78,8 @@ def signature(dbus_object, *, unpack=False):
             # It seems impossible to force a dbus-python Dictionary value
             # to have this property; the Dictionary constructor prevents it.
             raise IntoDPSignatureError(
-                f"the dbus-python Dictionary object {dbus_object} "
-                f"does not have a valid signature",
+                "the dbus-python Dictionary object %s does not have a valid signature"
+                % dbus_object,
                 dbus_object,
             )  # pragma: no cover
 
@@ -86,8 +87,8 @@ def signature(dbus_object, *, unpack=False):
             # It seems impossible to force a dbus-python Dictionary value
             # to have this property; the Dictionary constructor prevents it.
             raise IntoDPSignatureError(
-                f"the dbus-python Dictionary object {dbus_object} "
-                f"has different signatures for different keys",
+                "the dbus-python Dictionary object %s has different signatures for different keys"
+                % dbus_object,
                 dbus_object,
             )  # pragma: no cover
 
